/*-----------------------------------------------------------------------------
 * Name:    Thermometer_DS75.c
 * Purpose: Thermometer DS75 interface
 * Rev.:    1.0.0
 *----------------------------------------------------------------------------*/

/* Copyright (c) 2013 - 2018 ARM LIMITED

   All rights reserved.
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
   - Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
   - Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
   - Neither the name of ARM nor the names of its contributors may be used
     to endorse or promote products derived from this software without
     specific prior written permission.
   *
   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL COPYRIGHT HOLDERS AND CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
   ---------------------------------------------------------------------------*/

#include "bsp.h"
#include "i2cdrv.h"
#include "tempsens.h"
#include "Board_Thermometer.h"

/**
  \fn          int32_t Thermometer_Initialize (void)
  \brief       Initialize thermometer
  \returns
   - \b  0: function succeeded
   - \b -1: function failed
*/
int32_t Thermometer_Initialize (void) {
  I2C_Init_TypeDef i2cInit = I2C_INIT_DEFAULT;

  /* Initialize I2C driver, using standard rate. Devices on DK itself */
  /* supports fast mode, but in case some slower devices are added on */
  /* prototype board, we use standard mode. */
  I2CDRV_Init(&i2cInit);

  return 0;
}

/**
  \fn          int32_t Thermometer_Uninitialize (void)
  \brief       De-initialize thermometer
  \returns
   - \b  0: function succeeded
   - \b -1: function failed
*/
int32_t Thermometer_Uninitialize (void) {
  return -1;
}

/**
  \fn          int32_t Thermometer_GetTemperature (void)
  \brief       Get last temperature measurement
  \returns     Temperature in 0.1C, or TEMPERATURE_INVALID in case of error
*/
int32_t Thermometer_GetTemperature (void) {
  TEMPSENS_Temp_TypeDef temp;
  int32_t t;

  if (TEMPSENS_TemperatureGet(I2C0, TEMPSENS_DK_ADDR, &temp) == 0) {
    if (temp.f < 0) {
      temp.f = -temp.f;
    }
    t = temp.i * 10 + temp.f / 1000;
    return t;
  }

  return TEMPERATURE_INVALID;
}
